@@ -51,7 +51,7 @@ class Image(object):
             current_screen = pyautogui.screenshot(region=self.region)
 
         if debug:
-            current_screen.save('debug_screen.png')
+            current_screen.save("debug_screen.png")
 
         img_rgb = np.array(current_screen)
         img_gray = cv2.cvtColor(img_rgb, cv2.COLOR_BGR2GRAY)
@@ -179,7 +179,7 @@ class Image(object):
             current_screen = pyautogui.screenshot(region=self.region)
 
         if debug:
-            current_screen.save('debug_screen.png')
+            current_screen.save("debug_screen.png")
 
         img_rgb = np.array(current_screen)
         img_gray = cv2.cvtColor(img_rgb, cv2.COLOR_BGR2GRAY)
@@ -227,7 +227,7 @@ class Image(object):
             current_screen = pyautogui.screenshot(region=self.region)
 
         if debug:
-            current_screen.save('debug_screen.png')
+            current_screen.save("debug_screen.png")
 
         img_rgb = np.array(current_screen)
         img_gray = cv2.cvtColor(img_rgb, cv2.COLOR_BGR2GRAY)
@@ -402,14 +402,24 @@ class Image(object):
         self.set_region(x - width, y - height, x + width, y + height, debug=debug)
         return
 
-    def set_region_around_image(self, image, precision=0.8, debug=False):
+    def set_region_around_image(self, image, precision=0.8, padding=0, debug=False):
         """ Set a specific region on screen where the image given has been found.
 
             Parameters
             ----------
+            image: str
+                The path to the image we are looking for.
+            precision: double, optional
+                The percentage of recognition to use. Default is << 0.8 >>, meaning 80% similar.
+            padding: int, optional
+                The padding around the image to get a bigger region than the image size.
             debug: bool, optional
                 The activation of the debug mode. If << True >> takes a screenshot of the set region.
                 Default is << False >>.
+
+            Return
+            ------
+                The region where the image is.
         """
 
         if self.region is not None:
@@ -418,7 +428,7 @@ class Image(object):
         current_screen = pyautogui.screenshot()
 
         if debug:
-            current_screen.save('debug_screen.png')
+            current_screen.save("debug_screen.png")
 
         img_rgb = np.array(current_screen)
         img_gray = cv2.cvtColor(img_rgb, cv2.COLOR_BGR2GRAY)
@@ -430,8 +440,9 @@ class Image(object):
 
         if max_val < precision:
             return False
-
-        self.set_region(x1=max_loc[0], y1=max_loc[1], x2=max_loc[0] + w, y2=max_loc[1] + h)
+        region = (max_loc[0] - padding, max_loc[1] - padding, max_loc[0] + w + padding, max_loc[1] + h + padding)
+        self.set_region(region=region, debug=debug)
+        return region
 
     def release_region(self):
         """ Release the grabbed region.
